@@ -221,7 +221,7 @@ def performAnalysis(
 
     splinesLocParams = {}
     for s in params['splines']:
-        splinesLocParams[s] = liga.createParamSpline(splinesLoc[s])
+        splinesLocParams[s] = vtkh.createParamSpline(splinesLoc[s])
         
     ligaPaths = {}
     ligaLengths = {}
